@@ -9,7 +9,7 @@ import logging
 import configobj
 import validate
 
-from commodity.log import CapitalLoggingFormatter, CallerData
+from commodity.log import CapitalLoggingFormatter
 from commodity.pattern import Bunch
 
 from . import gvars
@@ -98,7 +98,7 @@ class StatusFilter(logging.Filter):
         except AttributeError:
             pass
 
-        record.msg = msg.safe_substitute(values) + term().normal
+        record.msg = "{0}{1}".format(msg.safe_substitute(values), term().normal)
         return True
 
 
@@ -110,7 +110,7 @@ def update_obj(dst, src):
 def load_default_config(dest):
     config = configobj.ConfigObj(configspec=PREGO_SPECS)
     config.validate(validate.Validator())
-    update_obj(dest, config)
+    update_obj(dest, config['ui'])
 
 
 def set_testpath():
